/* **************************************************************************
 *    Copyright (C) 2005 by Rob Brown                                       *
 *    rob@cobbleware.com                                                    *
 *                                                                          *
 *    C Implementation: sdk2x_system                                        *
 *                                                                          *
 *    This program is free software; you can redistribute it and/or modify  *
 *    it under the terms of the GNU General Public License as published by  *
 *    the Free Software Foundation; either version 2 of the License, or     *
 *    (at your option) any later version.                                   *
 *                                                                          *
 *    This program is distributed in the hope that it will be useful,       *
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *    GNU General Public License for more details.                          *
 *                                                                          *
 *    You should have received a copy of the GNU General Public License     *
 *    along with this program; if not, write to the                         *
 *    Free Software Foundation, Inc.,                                       *
 *    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 * **************************************************************************/

#include "stdio.h"
#include "sdk2x/mmsp2.h"
#include "sdk2x/sdk2x_priv.h"

char sdk2x_private_string [200];

void sdk2x_SystemReboot (void)
{
	/* Disable the display controller */
	sdk2x_LcdDisable();

	/* Mask ALL interrupts */
	MSP_INTMASK = 0xFF8FFFE7;

	/* Disable the clock into the timer module */
	MSP_SYSCLKENREG &= (~0x80);

	/* Set reboot behaviour when watchdog reset occurs */
	MSP_BOOTCTRLREG = 4;

	/* Clear any timer interrupts that may be pending, and enable the
	* interrupt in the timer module */
	MSP_TSTATUS = 8;
	MSP_TINTEN = 8;
	MSP_SRCPEND = 32;
	MSP_INTPEND = 32;

	/* Enable the watchdog reset */
	MSP_RSTCTRLREG = 0x100;

	/* Enable the Timer module interrupt */
	MSP_INTMASK &= (~0x20);

	/* Set the watchdog compare to fire in 50 counts, or 6.78us at 7.3728MHz */
	MSP_TMATCH3 = MSP_TCOUNT + 50;

	/* Set match 3 to be watchdog reset rather than an interrupt */
	MSP_TCONTROL = 3;

	/* Enable the clock into the timer module */
	MSP_SYSCLKENREG |= 0x80;

	/* Idle, waiting for reset */
	while (1);
}

static unsigned int CalcPll (unsigned short pll)
{
	unsigned int temp1, temp2;

	temp1 = 7372800 * ((unsigned int)(((pll >> 8)&0xff)+8));
	temp2 = ((unsigned int)(((pll >> 2)&0x03f)+2)) * ( 1 << ((unsigned int)(pll & 3)));
	return temp1 / temp2;
}

unsigned int sdk2x_GetFPLL (void)
{
	return CalcPll (MSP_FPLLVSETREG);
}

unsigned int sdk2x_GetUPLL (void)
{
	return CalcPll (MSP_UPLLVSETREG);
}

unsigned int sdk2x_GetAPLL (void)
{
	return CalcPll (MSP_APLLVSETREG);
}

unsigned int sdk2x_SetFPLL (unsigned short FpllSetReg)
{
	int i;
	unsigned int imask;

	imask = MSP_INTMASK;

	/* Mask ALL interrupts */
	MSP_INTMASK = 0xFF8FFFE7;

	MSP_FPLLSETVREG = FpllSetReg;

	while (MSP_CLKCHGSTREG & 1);

	MSP_INTMASK = imask;

	for (i=0;(i<10000000) && (MSP_FPLLVSETREG != FpllSetReg); i++);

	return sdk2x_GetFPLL();
}

unsigned int sdk2x_SetUPLL (unsigned short UpllSetReg)
{
	int i;
	unsigned int imask;

	imask = MSP_INTMASK;

	/* Mask ALL interrupts */
	MSP_INTMASK = 0xFF8FFFE7;

	MSP_UPLLSETVREG = UpllSetReg;

	while (MSP_CLKCHGSTREG & 2);

	MSP_INTMASK = imask;

	for (i=0;(i<10000000) && (MSP_UPLLVSETREG != UpllSetReg); i++);

	return sdk2x_GetUPLL();
}

unsigned int sdk2x_SetAPLL (unsigned short ApllSetReg)
{
	int i;
	unsigned int imask;

	imask = MSP_INTMASK;

	/* Mask ALL interrupts */
	MSP_INTMASK = 0xFF8FFFE7;

	MSP_APLLSETVREG = ApllSetReg;

	while (MSP_CLKCHGSTREG & 4);

	MSP_INTMASK = imask;

	for (i=0;(i<10000000) && (MSP_APLLVSETREG != ApllSetReg); i++);

	return sdk2x_GetAPLL();
}

void sdk2x_SysInitTable (const sdk2x_RegisterTable_t *pTable)
{
	while (pTable->pointer)
	{
		switch (pTable->size)
		{
			case 1:
				*((unsigned char *)pTable->pointer) = (unsigned char)pTable->value;
				break;
			case 2:
				*((unsigned short *)pTable->pointer) = (unsigned short)pTable->value;
				break;
			case 4:
				*((unsigned int *)pTable->pointer) = (unsigned int)pTable->value;
				break;
		}
		pTable++;
	}
}

